#####################################################
##                                                 ##
##       Wild-capture and reproductive success     ##
##                                                 ##
##   Predictions and figures for the manuscript    ##
##                                                 ##
##            LAHDENPERA ET AL 2019                ##
##                                                 ##
#####################################################

# Script to import data supporting the manuscript and plot the figures. Script
# separated in to the following sections:
#
# 1) Lifetime probability of reproduction - Figure 1
# 2) Age-specific reproduction probability - Figure 2
# 3) Time since capture - Figure 3
# 4) Age at first reproduction - Figure 4
# 5) Calf survival to age 5 - Figure 5
#
# For further info on the data in each file, see readme.txt 

require(tidyverse)
require(lme4)

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
##### 1. Lifetime probability of reproduction #####

load("lifetime_reproduction_data.RData", verbose = T)

## 1a. Having a look at the summary data for the figure
glimpse(lifetime_reproduction_summary)

## 1b. Having a look at the lifetime reproduction probability model
summary(lifetime_reproduction_model)

## 1c. Having a look at the average lifetime reproduction probabilities for
##     captive-born and wild-caught females
average_lifetime_reproduction

## 1d. Plotting figure 1
ggplot(lifetime_reproduction_summary, 
       aes(x = Origin, y = mnLR, fill = Origin)) +
  geom_violin(adjust = 0.8) +
  geom_boxplot(width = 0.2) +
  scale_x_discrete(name = NULL, labels = c("Captive-born", "Wild-caught")) +
  scale_fill_manual(values = c("grey80", "firebrick"),
                    name = NULL, guide = F) +
  labs(y = "Mean lifetime reproductive probability")  +
  theme_bw(base_size = 18) +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_blank())

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
##### 2. Age-specific reproduction probability #####

load("age_specific_data.RData", verbose = T)

## 2a. Having a look at the fitted and raw age-specific data summaries
glimpse(fitted_data_1960cohort) # fitted data for the 1960 birth cohort
glimpse(raw_data_summary) # raw data averages

## 2b. Having a look at the age at capture summary data
glimpse(age_at_capture_data)

## 2c. Having a look at the best model for age-specific reproduction
summary(best_agespecific_model)

## 2d. Plotting figure 2a
ggplot(fitted_data_1960cohort, aes(x = age, y = mnfit, colour = Origin, 
                                   group = interaction(Origin, age_factor))) +
  geom_point(data = raw_data_summary, aes(x = age, y = mnb, 
                                          group = NULL, size = n), alpha = 0.7) +
  geom_smooth(size = 1.1, se = F, stat = "identity") +
  scale_size_continuous(range = c(2,8), guide = F) +
  scale_color_manual(values = c("grey20", "firebrick"),
                     name = NULL, labels = c("Captive-born", "Wild-caught")) +
  scale_x_continuous(breaks = seq(0,70,by = 5),
                     labels = c(0,"",10,"",20,"",30,"",40,"",50,"",60,"",70),
                     limits = c(0,70)) +
  labs(x = NULL, y = "Mean annual birth rate", tag = "a)") +
  theme_bw(base_size = 18) +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_blank(),
        legend.position = c(0.85,0.92), 
        legend.text = element_text(size = 11),
        legend.background = element_blank()) 

## 2e. Plotting figure 2b
ggplot(age_at_capture_data, aes(x = age, y = mnfit, colour = aac, 
                 group = interaction(aac, age_factor), size = NULL)) +
  geom_line(size = 1.1) +
  coord_cartesian(ylim = c(0,0.105)) +
  scale_colour_manual(name = "Age at Capture",
                      values = c("grey20",viridis::inferno(10)[7:4]),
                      labels = c("Captive-born", "5", "13", "20", "30")) + 
  scale_x_continuous(breaks = seq(0,70,by = 5), 
                     labels = c(0,"",10,"",20,"",30,"",40,"",50,"",60,"",70),
                     limits = c(0,70)) +
  scale_size_continuous(range = c(1,8), guide = FALSE) +
  labs(x = "Age", y = "Mean annual birth rate", tag = "b)") +
  theme_bw(base_size = 18) +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_blank(),
        legend.position = c(0.85,0.76), 
        legend.text = element_text(size = 11),
        legend.title = element_text(size = 13),
        legend.background = element_blank())

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
##### 3. Time since capture #####

## 3a. Looking at the time since capture data
glimpse(time_since_capture_data)

cb_birth <- 0.04618253 # mean birth rate for captive-born females

## 3b. Plotting figure 3
ggplot(time_since_capture_data, aes(x = time_since_capture, y = mn)) +
  geom_hline(yintercept = cb_birth, linetype = "dashed") +
  geom_point(aes(size = n), alpha =0.9, colour = "firebrick") +
  geom_line(aes(y = mnf), size = 1.3, colour = "firebrick") +
  scale_size_continuous(range = c(1,7), guide = F) +
  scale_x_continuous(breaks = seq(0,20,by = 5), 
                     labels = seq(0,20,by = 5),limits = c(0,20)) +
  scale_y_continuous(breaks = seq(0,0.08,by = 0.01), 
                     labels = c("0.00", "", "0.02", "", 
                                "0.04","", "0.06", "", "0.08"),
                     limits = c(0,0.08)) +
  labs(x = "Years since capture", y = "Mean annual birth rate") +
  theme_bw(base_size = 16) +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_blank(),
        legend.position = c(0.80,0.92), 
        legend.text = element_text(size = 11),
        legend.background = element_blank())

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
##### 4. Age at first reproduction #####

load("age_at_first_reproduction_data.RData", verbose = T)

## 4a. Having a look at the age at first reproduction data
glimpse(age_at_first_reproduction_data)

## 4b. Having a look at the age at first reproduction model 
summary(age_at_first_reproduction_model)

## 4c. Plotting figure 4
ggplot(age_at_first_reproduction_data, 
       aes(x = Origin, y = AFR, fill = Origin, group = Origin)) + 
  geom_violin(adjust = 0.8) +
  geom_boxplot(width = 0.2,show.legend = F) +
  scale_x_discrete(name = NULL, labels = c("Captive-born", "Wild-caught")) +
  scale_y_continuous(breaks = seq(0,50,by = 5), 
                     labels = c("0", "", "10", "", "20","", 
                                "30", "", "40", "", "50"), 
                     limits = c(0,53)) +
  scale_fill_manual(values = c("grey80", "firebrick"),
                    name = NULL, guide = F) +
  labs(y = "Age at first reproduction") +
  theme_bw(base_size = 18) +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_blank()) 

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
##### 5. Calf survival to age 5 #####

load("calf_mortality_data.RData", verbose = T)

## 5a. Having a look at the calf mortality data
glimpse(calf_mortality_data)

cbdat <- data.frame(tsmc = 0, rawmort = calf_mortality_data$RawmortalityCB[1]) ## Data with calf mortality for captive-born females

## 5b. Plotting figure 5
ggplot(calf_mortality_data, 
                     aes(x = TimesincecapMUM, y = RawMortalityWC)) +
  geom_hline(yintercept = calf_mortality_data$MortalityCB[1], 
             colour = "grey20",
             size = 0.8) +
  geom_point(aes(size = RawtotalN), colour = "firebrick", alpha = 0.7) +
  geom_point(data = cbdat, 
             aes(x = tsmc, y = rawmort), 
             colour = "grey20", alpha = 0.7, size = 5) +
  geom_line(aes(y = MortalityWC), size = 1, colour = "firebrick") +
  scale_size_continuous(range = c(1,7), guide = F) +
  scale_x_continuous(breaks = seq(0,55,by = 5),
                     labels = c(0,"",10,"",20,"",30,"",40,"",50,""),
                     limits = c(0,55)) +
  coord_cartesian(ylim = c(0,0.2)) +
  labs(x = "Years since mothers capture", 
       y = "Probability of calf mortality") +
  theme_bw(base_size = 19) +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_blank(),
        legend.text = element_text(size = 11),
        legend.background = element_blank())


#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


